
# Slot: object




URI: [biolink:organism_taxon_to_organism_taxon_association_object](https://w3id.org/biolink/vocab/organism_taxon_to_organism_taxon_association_object)


## Domain and Range

[OrganismTaxonToOrganismTaxonAssociation](OrganismTaxonToOrganismTaxonAssociation.md) &#8594;  <sub>1..1</sub> [OrganismTaxon](OrganismTaxon.md)

## Parents

 *  is_a: [object](object.md)

## Children

 *  [organism taxon to organism taxon interaction➞object](organism_taxon_to_organism_taxon_interaction_object.md)
 *  [organism taxon to organism taxon specialization➞object](organism_taxon_to_organism_taxon_specialization_object.md)

## Used by

 * [OrganismTaxonToOrganismTaxonAssociation](OrganismTaxonToOrganismTaxonAssociation.md)
